<?php
/**
 *
 */
 
class BlocksWidget extends CWidget
{
	/**
	 * @property array
	 * The array of blocks.
	 */
	public $blocks = array(); 
	 
	/**
	 * @property string
	 * The region where the blocks are to be rendered.
	 */
	public $location;
	 
	/**
	 * @property array
	 * Attributes to be applied to the {@link blocksTagName container tag}.
	 */
	public $htmlOptions = array();
	 
	/**
	 * @property string
	 * The name of the container tag for the blocks to be rendered.
	 */
	public $blocksTagName = 'div';
	
	/**
	 * @property string
	 * The default attribute applied to the {@link blocksTagName container tag}.
	 */
	public $blocksCssClass = 'blocks';
	 
	/**
	 * @property string 
	 * The default attribute applied to the {@link blockTagName container tag}.
	 */
	public $blockCssClass = 'block';
	
	/**
	 * @property string
	 * The name of the container tag for the block to be rendered.
	 */
	public $blockTagName = 'div';
	
	/**
	 *
	 */
	public $loadDbBlocks = false;

	/**
	 *
	 */
	public function init()
	{
		parent::init();
		if(!isset($this->blocks) || is_null($this->blocks))
		{
			$owner = $this->getOwner();
			$this->blocks = property_exists($owner, 'blocks') && isset($owner->blocks) ? $owner->blocks : array();
		}
	}
	
	/**
	 *
	 */
	public function run()
	{
		if(!isset($this->location))
			return;
		$dbBlocks = array();
		if($this->loadDbBlocks)
			$dbBlocks = $this->getDbBlocks($this->location);
		$blocks = isset($this->blocks[$this->location]) ? $this->blocks[$this->location] : array();
		
		foreach($dbBlocks as $key => $dbBlock)
		{
			if(!isset($blocks[$key]))
				$blocks[$key] = $dbBlock;
		}
		$this->renderBlocks($blocks);
	}
	
	/**
	 * @param array The blocks to be rendered.
	 */
	public function renderBlocks($blocks = array())
	{
		if(count($blocks))
		{
			ksort($blocks);
			if(!count($this->htmlOptions))
				$this->htmlOptions = array('class'=>$this->blocksCssClass);
			echo CHtml::openTag($this->blocksTagName, $this->htmlOptions);
			foreach($blocks as $block)
			{
				$this->renderBlock($block);
			}
			echo CHtml::closeTag($this->blocksTagName);
		}
	}
	
	/**
	 * @param array The block to be rendered.
	 */
	public function renderBlock($block = array())
	{
		if(isset($block['content']))
		{
			if(!isset($block['htmlOptions']))
				$block['htmlOptions'] = array('class'=>$this->blockCssClass);
			echo CHtml::openTag($this->blockTagName, $block['htmlOptions']);
			echo $block['content'];
			echo CHtml::closeTag($this->blockTagName);
		}
	}
	
	/**
	 *
	 */
	public function getDbBlocks($location)
	{
		$blocks = array();
		
		if(!empty($location))
		{
			$block = Block::model()->with(array('blockItems'))->find('location=:location', array(
				':location'=>$location,
			));
			
			foreach($block->blockItems as $blockItem)
			{
				$blocks[$blockItem->position] = array(
					'content' => (int)$blockItem->static === BlockItem::STATIC_YES ? $blockItem->content : eval($blockItem->content),
				);
			}
		}
		return $blocks;
	}
}