<?php

/**
 * This is the model class for table "block_item".
 *
 * The followings are the available columns in table 'block_item':
  * @property integer $id
  * @property integer $block_id
  * @property string $name
  * @property integer $position
  * @property string $content
  * @property integer $static
  */
class BlockItem extends CActiveRecord
{
	/**
	 *
	 */
	const STATIC_NO = 0;
	const STATIC_YES = 1;
	 
	/**
	 * Returns the static model of the specified AR class.
	 * @return BlockItem the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'block_item';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('block_id, name, position, content, static', 'required'),
			array('block_id, position, static', 'numerical', 'integerOnly'=>true),
			array('name', 'length', 'max'=>100),
			// The following rule is used by search().
			// Please remove those attributes that should not be searched.
			array('id, block_id, name, position, content, static', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'block' => array(self::BELONGS_TO, 'Block', 'block_id'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'block_id' => 'Block',
			'name' => 'Name',
			'position' => 'Position',
			'content' => 'Content',
			'static' => 'Static',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
	 */
	public function search()
	{
		// Warning: Please modify the following code to remove attributes that
		// should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);

		$criteria->compare('block_id',$this->block_id);

		$criteria->compare('name',$this->name,true);

		$criteria->compare('position',$this->position);

		$criteria->compare('content',$this->content,true);

		$criteria->compare('static',$this->static);

		return new CActiveDataProvider(get_class($this), array(
			'criteria'=>$criteria,
		));
	}
}