<?php

/**
 * This is the model class for table "site.private_message_out".
 */
class PrivateMessageOut extends CActiveRecord
{
	/**
	 * The followings are the available columns in table 'site.private_message_out':
	 * @var integer $id
	 * @var integer $to_user_id
	 * @var integer $from_user_id
	 * @var string $subject
	 * @var string $body
	 * @var integer $create_time
	 * @var integer $status
	 */

	/**
	 * Returns the static model of the specified AR class.
	 * @return PrivateMessageOut the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'site.private_message_out';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('to_user_id, from_user_id, subject, body, create_time, status', 'required'),
			array('to_user_id, from_user_id, create_time, status', 'numerical', 'integerOnly'=>true),
			array('subject', 'length', 'max'=>255),
			// The following rule is used by search().
			// Please remove those attributes that should not be searched.
			array('id, to_user_id, from_user_id, subject, body, create_time, status', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'fromUser' => array(self::BELONGS_TO, 'User', 'from_user_id'),
			'toUser' => array(self::BELONGS_TO, 'User', 'to_user_id'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'to_user_id' => 'To User',
			'from_user_id' => 'From User',
			'subject' => 'Subject',
			'body' => 'Body',
			'create_time' => 'Create Time',
			'status' => 'Status',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
	 */
	public function search()
	{
		// Warning: Please modify the following code to remove attributes that
		// should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);

		$criteria->compare('to_user_id',$this->to_user_id);

		$criteria->compare('from_user_id',$this->from_user_id);

		$criteria->compare('subject',$this->subject,true);

		$criteria->compare('body',$this->body,true);

		$criteria->compare('create_time',$this->create_time);

		$criteria->compare('status',$this->status);

		return new CActiveDataProvider(get_class($this), array(
			'criteria'=>$criteria,
		));
	}
}