<?php

/**
 * This is the model class for table "user".
 */
class User extends CActiveRecord
{
	/**
	 * The followings are the available columns in table 'user':
	 * @var integer $id
	 * @var string $username
	 * @var integer $primary_email_id
	 * @var string $password
	 * @var integer $status
	 * @var integer $create_time
	 * @var integer $last_update_time
	 * @var integer $last_login_time
	 * @var integer $last_active_time
	 * @var string $create_ip
	 * @var string $last_login_ip
	 */
	 
	/**
	 *
	 */
	const STATUS_DELETED  = 0;
	 
	/**
	 *
	 */
	const STATUS_DISABLED = 1;
	
	/**
	 *
	 */
	const STATUS_ENABLED  = 2;
	
	/**
	 *
	 */
	public $email;
	
	/**
	 *
	 */
	public $newPassword;
	 
	/**
	 * Returns the static model of the specified AR class.
	 * @return User the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'user';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('username, email, newPassword', 'required', 'on'=>'register'),
			array('username, newPassword', 'length', 'min'=>5,'max'=>32),
			array('email', 'length', 'max'=>'50'),
			array('email', 'email'),
			array('username', 'unique', 'on'=>'register'),
			array('email', 'unique', 'className'=>'UserEmail', 'attributeName'=>'email', 'on'=>'register'),
			// The following rule is used by search().
			// Please remove those attributes that should not be searched.
			array('id, username, primary_email_id, password, status, create_time, last_update_time, last_login_time, last_active_time, create_ip, last_login_ip', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'friendRequests' => array(self::HAS_MANY, 'FriendRequest', 'user1_id'),
			'friendships' => array(self::HAS_MANY, 'Friendship', 'user2_id'),
			'privateMessageIns' => array(self::HAS_MANY, 'PrivateMessageIn', 'to_user_id'),
			'privateMessageOuts' => array(self::HAS_MANY, 'PrivateMessageOut', 'to_user_id'),
			'emails' => array(self::HAS_MANY, 'UserEmail', 'user_id'),
			'emailConfirmations' => array(self::HAS_MANY, 'UserEmailConfirmation', 'user_id'),
			'passwordResets' => array(self::HAS_MANY, 'UserPasswordReset', 'user_id'),
			'profile' => array(self::HAS_ONE, 'UserProfile', 'user_id'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => Yii::t('application','ID'),
			'username' => Yii::t('application','Username'),
			'primary_email_id' => Yii::t('application','Primary Email'),
			'password' => Yii::t('application','Password'),
			'status' => Yii::t('application','Status'),
			'create_time' => Yii::t('application','Create Time'),
			'last_update_time' => Yii::t('application','Last Update Time'),
			'last_login_time' => Yii::t('application','Last Login Time'),
			'last_active_time' => Yii::t('application','Last Active Time'),
			'create_ip' => Yii::t('application','Create Ip'),
			'last_login_ip' => Yii::t('application','Last Login Ip'),
			'email' => Yii::t('application','Email'),
			'newPassword' => Yii::t('application','Password'),
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
	 */
	public function search()
	{
		// Warning: Please modify the following code to remove attributes that
		// should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);

		$criteria->compare('username',$this->username,true);

		$criteria->compare('primary_email_id',$this->primary_email_id);

		$criteria->compare('password',$this->password,true);

		$criteria->compare('status',$this->status);

		$criteria->compare('create_time',$this->create_time);

		$criteria->compare('last_update_time',$this->last_update_time);

		$criteria->compare('last_login_time',$this->last_login_time);

		$criteria->compare('last_active_time',$this->last_active_time);

		$criteria->compare('create_ip',$this->create_ip,true);

		$criteria->compare('last_login_ip',$this->last_login_ip,true);

		return new CActiveDataProvider(get_class($this), array(
			'criteria'=>$criteria,
		));
	}
	
	/**
	 *
	 */
	public function generatePassword()
	{
		return substr((string)uniqid(), 0, rand(8, 12));
	}
	
	/**
	 *
	 */
	public function encryptPassword($password)
	{
		return md5($password);
	}
	
	/**
	 *
	 */
	public function getPrimaryEmail($asString = true)
	{
		$model = UserEmail::model()->find('id=:id AND user_id=:user_id', array(
			':user_id'=>$this->id,
			':id'=>$this->primary_email_id,
		));

		return (model !== null) ? $asString ? $model->email : $model : null;
	}
	
	/**
	 *
	 */
	public function sendPassword($password)
	{
	}
	
	/**
	 *
	 */
	public function getDefaultStatus()
	{
		return self::STATUS_ENABLED;
	}
	
	/**
	 *
	 */
	public function beforeSave()
	{
		if(parent::beforeSave())
		{
			if($this->scenario === 'register')
			{
				$this->username = strtolower($this->username);
				$this->password = self::encryptPassword($this->newPassword);
				$this->status = self::getDefaultStatus();
				$this->create_time = time();
				$this->create_ip = Yii::app()->request->getUserHostAddress();
			}
			return true;
		}
		return false;
	}
	
	/**
	 *
	 */
	public function afterSave()
	{
		parent::afterSave();
	}
	
	/**
	 * Adds a UserEmail record for the User record.
	 * @param $email the email address.
	 * @param $setAsPrimary whether to set the new email as the user's primary email address or not.
	 * @param $confirmed whether the new email address is confirmed or not.
	 * @param $addConfirmation whether to add a UserEmailConfirmation record for the new email address or not.
	 * @param $sendConfirmation whether to send the confirmation to the user's email address or not.
	 * @return UserEmail the email record.
	 */
	public function addEmail($email, $setAsPrimary = false, $confirmed = false, $addConfirmation = true, $sendConfirmation = true)
	{
		$model = new UserEmail;
		$model->user_id = $this->id;
		$model->email = $email;
		$model->confirmed = $confirmed ? UserEmail::CONFIRMED_YES : UserEmail::CONFIRMED_NO;
		
		if(!$model->save(false))
		{
			Yii::log(Yii::t('application','Could not add email "{email}" for user "{user_id}".', array(
				'{email}'=>$model->email,
				'{user_id}'=>$this->id,
			)), CLogger::LEVEL_ERROR, 'application');
		}else{
			if($setAsPrimary)
			{
				if($this->getIsNewRecord())
					$this->setIsNewRecord(false);
				$this->saveAttributes(array(
					'primary_email_id'=>$model->id,
					'last_update_time'=>time(),
				));
			}
			if(!$model->getIsConfirmed() && $addConfirmation)
			{
				$model->addConfirmation($sendConfirmation);
			}
		}
		return $model;
	}
	
	/**
	 *
	 */
	public function addPasswordReset($send = true)
	{
		$resets = UserPasswordReset::model()->findAllByAttributes(array(
			'user_id'=>$this->id,
		));
		foreach($resets as $reset)
		{
			$reset->sendCancellation();
			$reset->delete();
		}

		$model = new UserPasswordReset;
		$model->user_id = $this->id;
		$model->code = UserPasswordReset::generateCode();
		$model->create_time = time();
		if(!$model->save(false))
		{
			Yii::log(Yii::t('application','Could not add password reset for user "{id}".', array(
				'{id}'=>$this->id,
			)), CLogger::LEVEL_ERROR, 'application');
		}else{
			if($send)
				$model->send();
		}
		return $model;
	}
}