<?php

/**
 * This is the model class for table "user_email".
 */
class UserEmail extends CActiveRecord
{
	/**
	 * The followings are the available columns in table 'user_email':
	 * @var integer $id
	 * @var integer $user_id
	 * @var string $email
	 * @var integer $confirmed
	 */

	/**
	 *
	 */
	const CONFIRMED_NO = 0;
	
	/**
	 *
	 */
	const CONFIRMED_YES = 1;
	 
	/**
	 * Returns the static model of the specified AR class.
	 * @return UserEmail the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'user_email';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('user_id, email, confirmed', 'required'),
			array('user_id, confirmed', 'numerical', 'integerOnly'=>true),
			array('email', 'length', 'max'=>50),
			// The following rule is used by search().
			// Please remove those attributes that should not be searched.
			array('id, user_id, email, confirmed', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'user' => array(self::BELONGS_TO, 'User', 'user_id'),
			'userEmailConfirmations' => array(self::HAS_MANY, 'UserEmailConfirmation', 'email_id'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => Yii::t('application', 'ID'),
			'user_id' => Yii::t('application', 'User'),
			'email' => Yii::t('application', 'Email'),
			'confirmed' => Yii::t('application', 'Confirmed'),
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
	 */
	public function search()
	{
		// Warning: Please modify the following code to remove attributes that
		// should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);

		$criteria->compare('user_id',$this->user_id);

		$criteria->compare('email',$this->email,true);

		$criteria->compare('confirmed',$this->confirmed);

		return new CActiveDataProvider(get_class($this), array(
			'criteria'=>$criteria,
		));
	}
	
	/**
	 *
	 */
	public function beforeSave()
	{
		if(parent::beforeSave())
		{
			$this->email = strtolower($this->email);
			return true;
		}
		return false;
	}
	
	/**
	 *
	 */
	public function addConfirmation($send = true)
	{
		$model = new UserEmailConfirmation;
		$model->user_id = $this->user_id;
		$model->email_id = $this->id;
		$model->code = UserEmailConfirmation::generateCode();
		$model->create_time = time();
		if(!$model->save(false))
		{
			Yii::log(Yii::t('application','Could not add confirmation for email "{email}".', array(
				'{email}'=>$this->email,
			)), CLogger::LEVEL_ERROR, 'application');
		}else{
			if($send)
				$model->send();
		}
		return $model;
	}
	
	/**
	 *
	 */
	public function getIsConfirmed()
	{
		return (int)$this->confirmed === self::CONFIRMED_YES;
	}
}