<?php

/**
 * This is the model class for table "user_email_confirmation".
 */
class UserEmailConfirmation extends CActiveRecord
{
	/**
	 * The followings are the available columns in table 'user_email_confirmation':
	 * @var integer $id
	 * @var integer $user_id
	 * @var integer $email_id
	 * @var string $code
	 * @var integer $create_time
	 */

	/**
	 * Returns the static model of the specified AR class.
	 * @return UserEmailConfirmation the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'user_email_confirmation';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('user_id, email_id, code, create_time', 'required'),
			array('user_id, email_id, create_time', 'numerical', 'integerOnly'=>true),
			array('code', 'length', 'max'=>32),
			// The following rule is used by search().
			// Please remove those attributes that should not be searched.
			array('id, user_id, email_id, code, create_time', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'user' => array(self::BELONGS_TO, 'User', 'user_id'),
			'email' => array(self::BELONGS_TO, 'UserEmail', 'email_id'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => Yii::t('application', 'ID'),
			'user_id' => Yii::t('application', 'User'),
			'email_id' => Yii::t('application', 'Email'),
			'code' => Yii::t('application', 'Code'),
			'create_time' => Yii::t('application', 'Create Time'),
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
	 */
	public function search()
	{
		// Warning: Please modify the following code to remove attributes that
		// should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);

		$criteria->compare('user_id',$this->user_id);

		$criteria->compare('email_id',$this->email_id);

		$criteria->compare('code',$this->code,true);

		$criteria->compare('create_time',$this->expiry_time);

		return new CActiveDataProvider(get_class($this), array(
			'criteria'=>$criteria,
		));
	}
	
	/**
	 *
	 */
	public static function generateCode()
	{
		return md5(uniqid().microtime());
	}
	
	/**
	 *
	 */
	public function send()
	{
		
	}
}